:orphan:

.. automodule:: sqlalchemy.ext.declarative

===============
Declarative API
===============

API Reference
=============

.. versionchanged:: 1.4  The fundamental structures of the declarative
   system are now part of SQLAlchemy ORM directly.   For these components
   see:

   * :func:`_orm.declarative_base`

   * :class:`_orm.declared_attr`

   * :func:`_orm.has_inherited_table`

   * :func:`_orm.synonym_for`

   * :meth:`_orm.as_declarative`

See :ref:`declarative_toplevel` for the remaining Declarative extension
classes.

